/*
 * CKEditor - The text editor for Internet - http://ckeditor.com
 * Copyright (C) 2003-2008 Frederico Caldeira Knabben
 *
 * == BEGIN LICENSE ==
 *
 * Licensed under the terms of any of the following licenses at your
 * choice:
 *
 *  - GNU General Public License Version 2 or later (the "GPL")
 *    http://www.gnu.org/licenses/gpl.html
 *
 *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
 *    http://www.gnu.org/licenses/lgpl.html
 *
 *  - Mozilla Public License Version 1.1 or later (the "MPL")
 *    http://www.mozilla.org/MPL/MPL-1.1.html
 *
 * == END LICENSE ==
 */
CKEDITOR.dialog.add( 'textfield', function( editor )
{
	var addChange = function( name, input ){
		var dialog = input.getDialog();
		if ( input.isChanged() || ( dialog.editMode == false && input.getValue() != '' ))
		{
			dialog.changedAttibutes[ name ] = input.getValue();
			return true;
		}
		return false;
	};

	// Function called in onShow to load selected element.
	var loadLink = function( editor, selection, ranges, element )
	{
		this.saveSelection();
		this.editObj = element;
		this.editMode = true;

		// Fill out all fields.
		readAttribute.apply( this, [ 'info', 'name', 'txtName' ] );
		readAttribute.apply( this, [ 'info', 'value', 'txtValue' ] );
		readAttribute.apply( this, [ 'info', 'type', 'cmbType' ] );
		readAttribute.apply( this, [ 'info', 'width', 'txtTextCharWidth' ] );
		readAttribute.apply( this, [ 'info', 'maxlength', 'txtMaxChars' ] );

		return false;
	};
	
	var readAttribute = function( page, attribute, input )
	{
		var attributeValue = this.editObj.getAttribute( attribute );
		this.setValueOf( page, input, attributeValue );

		return attributeValue;
	}
	
	return {
		title : editor.lang.textFieldProp,
		resizable : CKEDITOR.DIALOG_RESIZE_NONE,
		minWidth : 400,
		minHeight : 230,
		onOk : function()
		{
			this.editObj.setAttributes( this.changedAttibutes );

			if ( this.editMode == false )
			{
				// It doesn't work with IE.
				this.restoreSelection();
				this.clearSavedSelection();
				editor.insertElement( this.editObj );
			}
			return true;
		},
		onShow : function()
		{
			// Default: create a new element.
			this.editMode = false;
			
			// IE BUG: Selection must be in the editor for getSelection() to work.
			this.restoreSelection();

			var editor = this.getParentEditor(),
				selection = editor.getSelection(),
				ranges = selection.getRanges();
				
			// Check selection. Fill in all the relevant fields if there's already one link selected.
			if ( ranges.length == 1 )
			{
				ranges[0].enlarge( CKEDITOR.ENLARGE_ELEMENT );

				var rangeRoot = ranges[0].getCommonAncestor( true );
				var element = rangeRoot.getAscendant( 'input', true );
				if ( element )
				{
					var type = element.getAttribute( 'type' );
					if ( type == "text" || type == null )
					{
						loadLink.apply( this, [ editor, selection, ranges, element ] );
						selection.selectElement( element );
					}
				}
			}

			if ( this.editMode == false )	//New object.
				this.editObj = editor.document.createElement( 'input' );

			this.getContentElement( 'info', 'txtName' ).focus();
			this.changedAttibutes = new Array();
		},
		contents : [
			{
				id : 'info',
				label : editor.lang.textFieldProp,
				title : editor.lang.textFieldProp,
				accessKey : 'I',
				elements : [
					{
						type : 'hbox',
						widths : [ '50%', '50%' ],
						children :
						[
							{
								id : 'txtName',
								type : 'text',
								label : editor.lang.dlgTextName,
								'default' : '',
								accessKey : 'N',
								validate: function()
								{
									addChange( 'name', this );
									return true;
								}
							},
							{
								id : 'txtValue',
								type : 'text',
								label : editor.lang.dlgTextValue,
								'default' : '',
								accessKey : 'V',
								validate: function()
								{
									addChange( 'value', this );
									return true;
								}
							}
						]
					},
					{
						type : 'hbox',
						widths : [ '50%', '50%' ],
						children :
						[
							{
								id : 'txtTextCharWidth',
								type : 'text',
								label : editor.lang.dlgTextCharWidth,
								'default' : '',
								accessKey : 'C',
								style : 'width:50px',
								validate: function()
								{
									var func = CKEDITOR.dialog.validate.integer( editor.lang.dlgImgTypeNumber );
									var isValid = func.apply( this );
									if ( isValid )
										addChange( 'width', this );
									return isValid;
								}
							},
							{
								id : 'txtMaxChars',
								type : 'text',
								label : editor.lang.dlgTextMaxChars,
								'default' : '',
								accessKey : 'M',
								style : 'width:50px',
								validate: function()
								{
									var func = CKEDITOR.dialog.validate.integer( editor.lang.dlgImgTypeNumber );
									var isValid = func.apply( this );
									if ( isValid )
										addChange( 'maxlength', this );
									return isValid;
								}
							}
						]
					},
					{
						id : 'cmbType',
						type : 'select',
						label : editor.lang.dlgTextType,
						'default' : 'text',
						accessKey : 'M',
						items :
						[
							[ editor.lang.dlgTextTypeText, 'text' ],
							[ editor.lang.dlgTextTypePass, 'pass' ],
						],
						validate: function()
						{
							addChange( 'type', this );
							return true;
						}
					}
				]
			}
		]
	};
});
